@@ -166,7 +166,7 @@ impl WithPhrase for KeyPair {
 
 #[derive(Zeroize, Debug, Clone, PartialEq)]
 #[zeroize(drop)]
-pub struct SecretKey(schnorrkel::SecretKey);
+pub struct SecretKey(pub(crate) schnorrkel::SecretKey);
 
 impl SecretKey {
     /// Convert this SecretKey into an array of 64 bytes, corresponding to an Ed25519 expanded secret key.
@@ -643,6 +643,12 @@ impl SecretKeyTrait for EphemeralSecretKey {
     }
 }
 
+impl From<SecretKey> for EphemeralSecretKey {
+    fn from(sk: SecretKey) -> Self {
+        Self(sk.0.clone())
+    }
+}
+
 impl Generate for EphemeralSecretKey {
     fn generate() -> Self {
         Self::generate_with(&mut OsRng)
@@ -1171,4 +1177,12 @@ mod tests {
         assert_ne!(another_public.to_vec(), blinded_public.to_vec());
         assert_eq!(public.to_vec(), blinded_public.to_vec());
     }
+
+    #[test]
+    fn test_ephemeral_secret_key_from_secret_key() {
+        let sk = SecretKey::generate();
+        let esk: EphemeralSecretKey = sk.clone().into();
+
+        assert_eq!(sk.to_vec(), esk.to_vec());
+    }
 }
